import { NodeClass, QualifiedName } from "node-opcua-data-model";
import { NodeId, NodeIdLike } from "node-opcua-nodeid";
import { BaseNode as BaseNodePublic, UAReferenceType as UAReferenceTypePublic } from "../source";
import { Reference } from "./reference";
export declare const NamespaceOptions: {
    nodeIdNameSeparator: string;
};
export interface AddressSpacePartial {
    findNode(nodeId: NodeIdLike): BaseNodePublic | null;
    findReferenceType(refType: NodeIdLike, namespaceIndex?: number): UAReferenceTypePublic | null;
}
export interface ConstructNodeIdOptions {
    nodeId?: string | NodeIdLike | null;
    browseName: QualifiedName;
    nodeClass: NodeClass;
    references?: Reference[];
}
export declare class NodeIdManager {
    private _cache;
    private _reverseCache;
    private _internal_id_counter;
    private namespaceIndex;
    private addressSpace;
    constructor(namespaceIndex: number, addressSpace: AddressSpacePartial);
    setCache(cache: Array<[string, number, NodeClass]>): void;
    setSymbols(symbols: Array<[string, number, string]>): void;
    getSymbols(): Array<[string, number, string]>;
    getSymbolCSV(): string;
    buildNewNodeId(): NodeId;
    constructNodeId(options: ConstructNodeIdOptions): NodeId;
    findParentNodeId(options: ConstructNodeIdOptions): [NodeId, string] | null;
    private _addInCache;
    private _isInCache;
    private _getOrCreateFromName;
}
